@@ -23,7 +23,6 @@
 #ifndef GCSSPECIALQUERIES_H
 #define GCSSPECIALQUERIES_H
 
-#import <Foundation/NSObject.h>
 
 #import <GDLAccess/EOAdaptorChannel.h>
 
@@ -37,6 +36,15 @@
 - (NSString *) createFolderTableWithName: (NSString *) tableName;
 - (NSString *) createFolderACLTableWithName: (NSString *) tableName;
 
+- (NSString *) createSessionsFolderWithName: (NSString *) tableName;
+- (NSDictionary *) sessionsAttributeTypes;
+
+- (NSString *)createAdminFolderWithName:(NSString *)tableName;
+- (NSDictionary *)adminAttributeTypes;
+
+- (NSString *) updateCPathInFolderInfo:(NSString *)tableName
+withCPath2:(NSString *)c_path2;
+
 @end
 
 @interface EOAdaptorChannel (GCSSpecialQueries)
@@ -45,4 +53,15 @@
 
 @end
 
+/* interfaces exposed so that categories can be created from them */
+@interface GCSPostgreSQLSpecialQueries : GCSSpecialQueries
+@end
+
+@interface GCSMySQLSpecialQueries : GCSSpecialQueries
+@end
+
+@interface GCSOracleSpecialQueries : GCSSpecialQueries
+@end
+
+
 #endif /* GCSSPECIALQUERIES_H */
