@@ -1,8 +1,6 @@
 /* SOGoConstants.h - this file is part of SOGo
  *
- * Copyright (C) 2010 Inverse inc.
- *
- * Author: Ludovic Marcotte <lmarcotte@inverse.ca>
+ * Copyright (C) 2010-2021 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,6 +36,8 @@ typedef enum
   PolicyPasswordTooShort = 6,
   PolicyPasswordTooYoung = 7,
   PolicyPasswordInHistory = 8,
+  PolicyPasswordRecoveryFailed = 9,
+  PolicyPasswordRecoveryInvalidToken = 10,
   PolicyNoError = 65535,
 } SOGoPasswordPolicyError;
 
@@ -49,6 +49,15 @@ typedef enum
   EventCreated = 0,
   EventDeleted = 1,
   EventUpdated = 2,
-} SOGoEventOperation;
+  TaskCreated = 3,
+  TaskDeleted = 4,
+  TaskUpdated = 5,
+} SOGoComponentOperation;
+
+typedef enum
+{
+  SOGoPersonalFolder = 0,
+  SOGoCollectedFolder = 1,
+} SOGoFolderType;
 
 #endif /* _SOGOCONSTANTS_H_ */
