@@ -31,11 +31,12 @@
    * @desc The factory we'll use to register with Angular
    * @returns the Mailbox constructor
    */
-  Mailbox.$factory = ['$q', '$timeout', '$log', 'sgSettings', 'Resource', 'Message', 'Acl', 'Preferences', 'sgMailbox_PRELOAD', 'sgMailbox_BATCH_DELETE_LIMIT', function($q, $timeout, $log, Settings, Resource, Message, Acl, Preferences, PRELOAD, BATCH_DELETE_LIMIT) {
+  Mailbox.$factory = ['$q', '$timeout', '$log', '$rootScope', 'sgSettings', 'Resource', 'Message', 'Acl', 'Preferences', 'sgMailbox_PRELOAD', 'sgMailbox_BATCH_DELETE_LIMIT', function ($q, $timeout, $log, $rootScope, Settings, Resource, Message, Acl, Preferences, PRELOAD, BATCH_DELETE_LIMIT) {
     angular.extend(Mailbox, {
       $q: $q,
       $timeout: $timeout,
       $log: $log,
+      $rootScope: $rootScope,
       $$resource: new Resource(Settings.activeUser('folderURL') + 'Mail', Settings.activeUser()),
       $Message: Message,
       $$Acl: Acl,
@@ -45,6 +46,7 @@
       $refreshTimeout: null,
       $virtualMode: false,
       $virtualPath: false,
+      $searchMode: false,
       PRELOAD: PRELOAD,
       BATCH_DELETE_LIMIT: BATCH_DELETE_LIMIT
     });
@@ -169,6 +171,9 @@
       this.$visibleMessages = this.$messages;
       this.$selectedMessages = [];
     }
+    if (angular.isUndefined(this.$highlightWords)) {
+      this.$highlightWords = [];
+    }
     angular.extend(this, data);
     if (this.path) {
       this.id = this.$id();
@@ -242,6 +247,16 @@
       Mailbox.selectedFolder = this;
   };
 
+  /**
+   * @function setSearchMode
+   * @memberof Mailbox.prototype
+   * @desc Set search mode for controller
+   * @param {array} searchMode - a boolean
+   */
+  Mailbox.prototype.setSearchMode = function (searchMode) {
+    Mailbox.$searchMode = searchMode;
+  };
+
   /**
    * @function getLength
    * @memberof Mailbox.prototype
@@ -385,6 +400,27 @@
       // Sorting preferences are common to all mailboxes
       angular.extend(Mailbox.$query, sortingAttributes);
 
+    if (filters && filters.length > 0) {
+      // Remove highlight words
+      this.$highlightWords = [];
+      filters.forEach(filter => {
+        if ("subject_or_from" == filter.searchBy
+          || "contains" == filter.searchBy
+          || "body" == filter.searchBy
+          || "from" == filter.searchBy
+          || "to" == filter.searchBy
+          || "subject" == filter.searchBy) {
+          var words = filter.searchInput.split(" ");
+          words.forEach(word => {
+            var cleanedWord = word.trim().toLowerCase();
+            if (!this.$highlightWords.includes(cleanedWord)) {
+              this.$highlightWords.push(cleanedWord);
+            }
+          });
+        }
+      });
+    }
+
     angular.extend(options, { sortingAttributes: Mailbox.$query });
     if (angular.isDefined(filters)) {
       options.filters = _.reject(angular.copy(filters), function(filter) {
@@ -1069,6 +1105,7 @@
    * @returns a promise of the HTTP operation
    */
   Mailbox.prototype.$unwrap = function(futureMailboxData) {
+    Mailbox.$rootScope.$broadcast('beforeListRefresh');
     var _this = this,
         deferred = Mailbox.$q.defer();
 
@@ -1191,6 +1228,7 @@
 
         Mailbox.$log.debug('mailbox ' + _this.id + ' ready');
         _this.$isLoading = false;
+        Mailbox.$rootScope.$broadcast('listRefreshed');
         deferred.resolve(_this.$messages);
       });
     }, function(data) {
@@ -1249,4 +1287,23 @@
     Mailbox.$$resource.post(this.id, action);
   };
 
+  /**
+   * @function setHighlightWords
+   * @memberof Mailbox.prototype
+   * @desc Set highlight words when searching
+   * @param {array} highlightWords - a list of words
+   */
+  Mailbox.prototype.setHighlightWords = function (highlightWords) {
+    this.$highlightWords = highlightWords;
+  };
+
+  /**
+   * @function getHighlightWords
+   * @memberof Mailbox.prototype
+   * @desc Get highlight words when searching
+   * @returns a list of words
+   */
+  Mailbox.prototype.getHighlightWords = function () {
+    return this.$highlightWords;
+  };
 })();
