@@ -29,12 +29,12 @@ sqlscript=""
 function addField() {
     oldIFS="$IFS"
     IFS=" "
-    part="`echo -e \"ALTER TABLE $table ADD COLUMN c_categories VARCHAR(255);\\n\"`";
+    part="`echo -e \"ALTER TABLE $table ADD COLUMN c_category VARCHAR(255);\\n\"`";
     sqlscript="$sqlscript$part"
     IFS="$oldIFS"
 }
 
-tables=`psql -t -U $username -h $hostname $database -c "select split_part(c_quick_location, '/', 5) from $indextable where c_folder_type = 'Contact';"`
+tables=`psql -t -U $username -h $hostname $database -c "select split_part(c_quick_location, '/', 5) from $indextable where c_folder_type = 'Appointment';"`
 
 for table in $tables;
 do
